@@ -44,7 +44,7 @@ def startup(versionno):
         sys.stdout.write(version.cmdhelp + "\n")
         sys.exit(0)
 
-    for optlist in getopt(sys.argv[1:], 'P:1oa:c:d:u:h')[0]:
+    for optlist in getopt(sys.argv[1:], 'P:1oa:c:d:l:u:h')[0]:
         options[optlist[0]] = optlist[1]
 
     if '-h' in options:
@@ -71,9 +71,13 @@ def startup(versionno):
     config.read(configfilename)
 
     ui = offlineimap.ui.detector.findUI(config, options.get('-u'))
-    ui.init_banner()
     UIBase.setglobalui(ui)
 
+    if '-l' in options:
+        ui.setlogfd(open(options['-l'], 'wt'))
+
+    ui.init_banner()
+
     if '-d' in options:
         for debugtype in options['-d'].split(','):
             ui.add_debug(debugtype.strip())
@@ -89,6 +93,9 @@ def startup(versionno):
 
     lock(config, ui)
 
+    if '-l' in options:
+        sys.stderr = ui.logfile
+
     activeaccounts = config.get("general", "accounts")
     if '-a' in options:
         activeaccounts = options['-a']
